@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-
+import inspect
 try:
     import urlparse
 except ImportError:  # Python 3
@@ -55,6 +55,8 @@ def execute(self, *args, **kwargs):
     url = urlparse.urlunparse(['http', self.api.host, self.path, None, urlencode(parameters), None])
 
     response = requests.get(url).json
+    if inspect.ismethod(response):
+        response = response()
 
     if response['response_code'] != '200':
         raise DgisError(int(response['response_code']), response['error_message'], response['error_code'])
